@@ -1,5 +1,5 @@
 package HTML::Spelling::Site;
-
+$HTML::Spelling::Site::VERSION = '0.0.5';
 use strict;
 use warnings;
 
@@ -18,7 +18,7 @@ HTML site.
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -33,6 +33,10 @@ duplicate functionality for spell checking my web-sites. Currently
 documentation is somewhat lacking and the modules could use some extra
 automated tests, but I'm anxious to get something out the door.
 
+=head1 VERSION
+
+version 0.0.5
+
 =head1 SEE ALSO
 
 L<Test::HTML::Spelling> - possibly somewhat less generic than
@@ -55,8 +59,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Spelling-Site or by email to
-bug-html-spelling-site@rt.cpan.org.
+https://github.com/shlomif/html-spelling-site/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
