@@ -1,5 +1,5 @@
 package HTML::Spelling::Site::Checker;
-
+$HTML::Spelling::Site::Checker::VERSION = '0.0.5';
 use strict;
 use warnings;
 use autodie;
@@ -216,7 +216,7 @@ HTML::Spelling::Site::Checker - does the actual checking.
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -376,6 +376,10 @@ In t/html-spell-check.t :
 The instances of this class can be used to do the actual scanning of
 local HTML files.
 
+=head1 VERSION
+
+version 0.0.5
+
 =head1 METHODS
 
 =head2 my $obj = HTML::Spelling::Site::Checker->new({ whitelist_parser => $parser_obj, check_word_cb => sub { ... }, timestamp_cache_fn => '/path/to/timestamp-cache.json' })
@@ -420,8 +424,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Spelling-Site or by email to
-bug-html-spelling-site@rt.cpan.org.
+https://github.com/shlomif/html-spelling-site/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
