@@ -1,5 +1,5 @@
 package HTML::Spelling::Site::Finder;
-
+$HTML::Spelling::Site::Finder::VERSION = '0.0.5';
 use strict;
 use warnings;
 
@@ -51,7 +51,7 @@ a directory tree.
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -77,6 +77,10 @@ The instances of this class can be used to scan a directory tree of files
 ending with C<.html> and C<.xhtml> and to return a list of them as a sorted
 array reference.
 
+=head1 VERSION
+
+version 0.0.5
+
 =head1 METHODS
 
 =head2 ->new({ prune_cb => sub { ... }, root_dir => $root_dir })
@@ -111,8 +115,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Spelling-Site or by email to
-bug-html-spelling-site@rt.cpan.org.
+https://github.com/shlomif/html-spelling-site/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
