@@ -1,5 +1,5 @@
 package HTML::Spelling::Site::Whitelist;
-
+$HTML::Spelling::Site::Whitelist::VERSION = '0.0.5';
 use strict;
 use warnings;
 use autodie;
@@ -102,7 +102,10 @@ sub parse
                 }
             }
         }
-        push @{$self->_records}, $rec;
+        if (defined $rec)
+        {
+            push @{$self->_records}, $rec;
+        }
         close ($fh);
 
         foreach my $w (@{$self->_general_whitelist})
@@ -165,15 +168,15 @@ sub get_sorted_text
     map { "$_\n" }
     (
         "==== GLOBAL:", '',
-        @{_sort_words($self->_general_whitelist)}, '',
+        @{_sort_words([keys %_gen])},
         (map
             { my %found;
-                ("==== In: ".join(' , ', @{$_->{files}})), '',
+                ('',("==== In: ".join(' , ', @{$_->{files}})), '',
                 (@{ _sort_words(
                             [grep { !exists($_gen{$_}) and !($found{$_}++)} @{$_->{words}}]
                     )
                   }
-                ), ''
+                ))
             }
             sort { _rec_sorter($a->{files}, $b->{files}, 0) }
             @{$self->_records}
@@ -220,7 +223,7 @@ HTML::Spelling::Site::Whitelist - handles the whitelist file.
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -246,6 +249,10 @@ version 0.0.4
 The instances of this class can be used to manage a whitelist of words to
 spell check.
 
+=head1 VERSION
+
+version 0.0.5
+
 =head1 METHODS
 
 =head2 my $obj = HTML::Spelling::Site::Checker->new({ filename => './path/to/whitelist.txt'});
@@ -319,8 +326,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Spelling-Site or by email to
-bug-html-spelling-site@rt.cpan.org.
+https://github.com/shlomif/html-spelling-site/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
